Fetch ETF Holdings from Yahoo Finance
fetch_etf_holdings.RdRetrieves historical fund holdings (composition) for a given ETF ticker using tidyquant. This includes top holdings, sector weights, and asset allocation data.
fetch_etf_holdings.RdRetrieves historical fund holdings (composition) for a given ETF ticker using tidyquant. This includes top holdings, sector weights, and asset allocation data.